@@ -1,5 +1,3 @@
-context("User-defined unit conversion")
-
 test_that("we can convert between units with a user-defined function", {
   expect_error(as_units("apple"))
   expect_error(as_units("orange"))
@@ -24,9 +22,9 @@ test_that("we can convert between units with a user-defined function", {
   expect_equal(bananas + 3 * apples, (6 + 3 * 2 / 3) * as_units("banana"))
 
   # check dimensionless
-  install_unit("person", "unitless")
+  install_unit("person", "1")
   persons <- set_units(3, person)
-  expect_equal(persons, set_units(3, 1))
+  expect_true(persons == set_units(3, 1))
 
   # restore
   remove_unit(c("orange", "apple", "banana", "person"))
